import { Duration } from 'aws-cdk-lib';
import { IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueParser } from '../issue-manager';
import { IssuePluginBase, IssuePluginBaseProps } from '../issue-plugin-base';
import { IssueTrigger } from '../issue-trigger';
export declare class EcrImageScanSeverity {
    static readonly UNDEFINED: EcrImageScanSeverity;
    static readonly LOW: EcrImageScanSeverity;
    static readonly MEDIUM: EcrImageScanSeverity;
    static readonly HIGH: EcrImageScanSeverity;
    static readonly CRITICAL: EcrImageScanSeverity;
    static of(name: string, priority: number, standardized: string): EcrImageScanSeverity;
    readonly name: string;
    readonly priority: number;
    readonly standardized: string;
    private constructor();
}
export interface IEcrImageScanSeverityConfiguration {
    readonly levels: EcrImageScanSeverity[];
}
export declare class EcrImageScanSeverityConfiguration {
    static all(): IEcrImageScanSeverityConfiguration;
    static custom(...levels: EcrImageScanSeverity[]): IEcrImageScanSeverityConfiguration;
    static threshold(level: EcrImageScanSeverity): IEcrImageScanSeverityConfiguration;
}
export interface EcrScanFindingEventOptions {
    readonly overrides?: IssueHandlerOverride[];
    readonly severity?: IEcrImageScanSeverityConfiguration;
}
export interface EcrScanFindingProps extends IssuePluginBaseProps {
    readonly matchType?: string;
    readonly name?: string;
    readonly timeout?: Duration;
}
export declare class EcrScanFinding extends IssuePluginBase implements IIssueParser {
    static readonly MATCH_TYPE: string;
    static readonly SEVERITIES: EcrImageScanSeverity[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly handler: IStateMachine;
    readonly matchType: string;
    get triggers(): IssueTrigger[];
    constructor(scope: IConstruct, id: string, props?: EcrScanFindingProps);
    protected buildDescription(): string;
    private buildSeverityChain;
    bind(_scope: IConstruct): IssueTrigger[];
    protected buildSummary(): string;
    registerIssueTrigger(id: string, options?: EcrScanFindingEventOptions): IssueTrigger;
}
