import { IConstruct } from 'constructs';
import { IIpamPool, IIpv4IpamPool, IIpv6IpamPool } from '..';
export declare enum AddressFamily {
    IPV4 = "ipv4",
    IPV6 = "ipv6"
}
export interface CidrAssignmentCidrDetails {
    readonly family: AddressFamily;
    readonly cidr: string;
    readonly netmask: number;
}
export interface CidrAssignmentIpamDetails {
    readonly amazonAllocated?: boolean;
    readonly family: AddressFamily;
    readonly ipamPool?: IIpamPool;
    readonly netmask: number;
}
export interface CidrAssignmentDetails {
    readonly cidrDetails?: CidrAssignmentCidrDetails;
    readonly ipamDetails?: CidrAssignmentIpamDetails;
}
export interface CidrAssignmentBindOptions {
    readonly maxNetmask?: number;
    readonly minNetmask?: number;
}
export interface ICidrAssignment {
    getCidr(scope: IConstruct, id: string, options: CidrAssignmentBindOptions): CidrAssignmentCidrDetails;
    getCidrOrIpamConfiguration(options: CidrAssignmentBindOptions): CidrAssignmentDetails;
}
export interface IIpv4CidrAssignment extends ICidrAssignment {
}
export interface Ipv4CidrAssignmentCustomOptions {
    readonly cidr: string;
}
export interface Ipv4CidrAssignmentIpamPoolOptions {
    readonly allocationId?: string;
    readonly netmask?: number;
    readonly pool: IIpv4IpamPool;
}
export declare class Ipv4CidrAssignment {
    static custom(options: Ipv4CidrAssignmentCustomOptions): IIpv4CidrAssignment;
    static ipamPool(options: Ipv4CidrAssignmentIpamPoolOptions): IIpv4CidrAssignment;
}
export interface IIpv6CidrAssignment extends ICidrAssignment {
}
export interface Ipv6CidrAssignmentCustomOptions {
    readonly cidr: string;
}
export interface Ipv6CidrAssignmentIpamPoolOptions {
    readonly allocationId?: string;
    readonly netmask?: number;
    readonly pool: IIpv6IpamPool;
}
export declare class Ipv6CidrAssignment {
    static custom(options: Ipv4CidrAssignmentCustomOptions): IIpv6CidrAssignment;
    static ipamPool(options: Ipv6CidrAssignmentIpamPoolOptions): IIpv6CidrAssignment;
}
