import { IVpnGateway } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { ILocalVpnEndpoint, LocalVpnEndpointConfiguration } from '.';
/**
 * Specifies a VPN connection endpoint which routes to a VPN gateway on the AWS
 * side.
 */
export declare class VpnGatewayLocalVpnEndpoint implements ILocalVpnEndpoint {
    /**
     * The VPN gateway that serves as the local end of a VPN connection.
     *
     * @group Inputs
     */
    readonly vpnGateway: IVpnGateway;
    /**
     * Creates a new instance of the VpnGatewayLocalVpnEndpoint class.
     *
     * @param vpnGateway The VPN gateway that serves as the local end of a VPN
     * connection.
     */
    constructor(vpnGateway: IVpnGateway);
    /**
     * Produces a configuration that can be used when configuring the local
     * end of a VPN connection.
     *
     * @param _scope The construct configuring the VPN connection that will be
     * referencing the local endpoint.
     */
    bind(_scope: IConstruct): LocalVpnEndpointConfiguration;
}
