import { Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnTransitGatewayRoute } from 'aws-cdk-lib/aws-ec2';
import { Construct, IConstruct } from 'constructs';
import { ITransitGatewayRouteTable } from '.';
import { ITransitGatewayAttachment } from './transit-gateway-attachment-base';
/**
 * Represents a Transit Gateway Route in AWS.
 */
export interface ITransitGatewayRoute {
    /**
     * The ID of the Transit Gateway Route.
     */
    readonly transitGatewayRouteId: string;
}
/**
 * Configuration for TransitGatewayRoute resource.
 */
export interface TransitGatewayRouteProps extends ResourceProps {
    readonly attachment?: ITransitGatewayAttachment;
    readonly blackhole?: boolean;
    readonly cidr: string;
    readonly routeTable: ITransitGatewayRouteTable;
}
/**
 * Adds a routing rule for a transit gateway route table.
 */
export declare class TransitGatewayRoute extends Resource {
    /**
     * Imports an existing Transit Gateway Route using its route ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param transitGatewayRouteId The ID of the Transit Gateway route being
     * imported.
     * @returns An object representing the imported Transit Gateway route.
     */
    static fromTransitGatewayRouteId(scope: IConstruct, id: string, transitGatewayRouteId: string): ITransitGatewayRoute;
    readonly attachment?: ITransitGatewayAttachment;
    readonly blackhole?: boolean;
    readonly cidr: string;
    readonly routeTable: ITransitGatewayRouteTable;
    readonly resource: CfnTransitGatewayRoute;
    readonly transitGatewayRouteId: string;
    /**
       * Creates a new instance of the TransitGatewayAttachment class.
       *
       * @param scope A CDK Construct that will serve as this stack's parent in the construct tree.
       * @param id A name to be associated with the stack and used in resource naming. Must be unique
       * within the context of 'scope'.
       * @param props Arguments related to the configuration of the resource.
       */
    constructor(scope: Construct, id: string, props: TransitGatewayRouteProps);
}
