import { ArnFormat, IResolvable, Token } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
export interface ResourceIdentities {
    arn: string;
    id: string;
}
export interface IIdentityParser {
    buildArn(id: string): string;
    parseArn(arn: string, resourceName?: string): string;
}
export interface ResourceSpecification {
    readonly account?: string;
    readonly arnFormat: ArnFormat;
    readonly parser?: IIdentityParser;
    readonly partition?: string;
    readonly region?: string;
    readonly resource?: string;
    readonly scope: IConstruct;
    readonly service: string;
}
export declare class DefaultIdentityParser implements IIdentityParser {
    readonly spec: ResourceSpecification;
    constructor(spec: ResourceSpecification);
    buildArn(id: string): string;
    parseArn(arn: string, resourceName?: string): string;
}
export declare function resolveIdentities(spec: ResourceSpecification, arn?: string, id?: string): ResourceIdentities;
export declare function optionalBoolean(scope: IConstruct, id: string, field: string, value?: boolean): IResolvable;
export declare function optionalNumber(scope: IConstruct, id: string, field: string, value?: number): number;
export declare function optionalString(scope: IConstruct, id: string, field: string, value?: string): string;
export interface ResourceImporterProps {
    readonly account?: string;
    readonly arnFormat: ArnFormat;
    readonly parser?: IIdentityParser;
    readonly partition?: string;
    readonly region?: string;
    readonly resource?: string;
    readonly service: string;
}
export declare class ResourceImporter {
    readonly id: string;
    readonly props: ResourceImporterProps;
    readonly scope: IConstruct;
    constructor(scope: IConstruct, id: string, props: ResourceImporterProps);
    resolveProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: Token;
    };
    resolveIdentities(arn?: string, id?: string): ResourceIdentities;
}
